@@ -6,13 +6,26 @@ import numpy as np
 from scipy.cluster.vq import whiten
 import matplotlib.pyplot as plt
 from phantominator import radial, kspace_shepp_logan
-from skimage.metrics import normalized_root_mse as compare_nrmse # pylint: disable=E0611,E0401
-from skimage.metrics import structural_similarity as compare_ssim # pylint: disable=E0611,E0401
+try:
+    from skimage.metrics import normalized_root_mse as compare_nrmse  # pylint: disable=E0611,E0401
+    from skimage.metrics import structural_similarity as compare_ssim  # pylint: disable=E0611,E0401
+except ImportError:
+    from skimage.measure import compare_nrmse, compare_ssim
 from skimage.morphology import convex_hull_image
 from skimage.filters import threshold_li
 
 from pygrappa import radialgrappaop, grog
 
+
+def ifft(x0):
+    return np.fft.fftshift(np.fft.ifft2(np.fft.ifftshift(
+        x0, axes=(0, 1)), axes=(0, 1)), axes=(0, 1))
+
+
+def sos(x0):
+    return np.sqrt(np.sum(np.abs(x0)**2, axis=-1))
+
+
 if __name__ == '__main__':
 
     # Radially sampled Shepp-Logan
@@ -21,7 +34,7 @@ if __name__ == '__main__':
     kx = np.reshape(kx, (N, spokes), 'F').flatten().astype(np.float32)
     ky = np.reshape(ky, (N, spokes), 'F').flatten().astype(np.float32)
     k = kspace_shepp_logan(kx, ky, ncoil=nc).astype(np.complex64)
-    k = whiten(k) # whitening seems to help conditioning of Gx, Gy
+    k = whiten(k)  # whitening seems to help conditioning of Gx, Gy
 
     # # Instead of whitening, maybe you prefer to reduce coils:
     # nc = 4
@@ -57,14 +70,10 @@ if __name__ == '__main__':
     kc = whiten(kc)
     outside = np.argwhere(
         np.sqrt(tx**2 + ty**2) > np.max(kx)).squeeze()
-    kc[outside] = 0 # keep region of support same as radial
+    kc[outside] = 0  # keep region of support same as radial
     kc = np.reshape(kc, (N, N, nc), order='F')
 
     # Make sure we gridded something recognizable
-    ifft = lambda x0: np.fft.fftshift(np.fft.ifft2(np.fft.ifftshift(
-        x0, axes=(0, 1)), axes=(0, 1)), axes=(0, 1))
-    sos = lambda x0: np.sqrt(np.sum(np.abs(x0)**2, axis=-1))
-
     nx, ny = 1, 3
     plt.subplot(nx, ny, 1)
     true = sos(ifft(kc))
