@@ -2,10 +2,11 @@
 
 import numpy as np
 
+
 def grappa(kspace, calib, kernel_size=(5, 5)):
     '''GRAPPA.'''
 
-    mask = np.abs(kspace[..., 0]) > 0
+    # mask = np.abs(kspace[..., 0]) > 0
 
 
 if __name__ == '__main__':
